#! /bin/bash
# -----------------------------------------------------------------------------
# f2cad: Convert Fortran to C++ AD Types: Copyright (C) 2005-10 Bradley M. Bell
# Authors:  Bradley M. Bell    bradbell at washington dot edu
# License:  GNU Public License Version 2 or higher
# -----------------------------------------------------------------------------
# check initial working directory
dir=`pwd | sed -e 's|.*/[fF]2c[aA][dD]/||'`
if [ "$dir" != "trunk" ]
then
	echo "new_stable.sh: must execute this script in the trunk"
	exit 1
fi
#
echo "Getting current revision number for version of trunk"
rev_trunk=`svn info --revision HEAD | \
	grep '^Revision:' | sed -e 's|^Revision: *||'`
echo "rev_trunk=$rev_trunk"
#
# number for the stable version we are creating
stable_version=`date +%F | sed -e 's/-//g' -e 's|^|0.|'`
#
# check that the documentation is up to date
doc_version=`grep '$section' f2cad.omh | \
	sed -e 's|.*f2cad-\([0-9]\{8\}\).*|0.\1|'`
if [ "$doc_version" != "$stable_version" ]
then
	echo "new_stable.sh: run ./copy_doc.sh to bring doc version up to date"
	echo "new_stable.sh: stable_version = $stable_version"
	echo "new_stable.sh: doc_version    = $doc_version"
	exit 1
fi
#
# web address for trunk, stable, and release
repository="https://projects.coin-or.org/svn/CoinBazaar"
rep_trunk="$repository/projects/f2cAD/trunk"
rep_stable="$repository/projects/f2cAD/stable/$stable_version"
rep_release="$repository/projects/f2cAD/releases/$stable_version.0"
rep_html="$repository/html/f2cAD"
#
# create the new stable version
msg="[f2cad/stable] Create f2cad/stable/$stable_version 
from f2cad/trunk at revision $rev_trunk."
echo "svn copy $rep_trunk $rep_stable -m \"$msg\""
if ! svn copy  $rep_trunk $rep_stable -m "$msg"
then
	"new_stable.sh: Cannot create $rep_stable"
	exit 1
fi
#
# add a copy of the documentation to the stable version
msg="[f2cad/stable] Add documentation corresponding to this stable version"
echo "svn copy $rep_html $rep_stable/doc -m \"$msg\""
if ! svn copy $rep_html $rep_stable/doc -m "$msg"
then
	"new_stable.sh: Cannot copy documentation for this stable version"
	exit 1
fi
#
# create the new release version
msg="[f2cad/releases] Create f2cad/releases/$stable_version.0 
from f2cad/trunk at revision $rev_trunk."
echo "svn copy $rep_stable $rep_release -m \"$msg\""
if ! svn copy  $rep_stable $rep_release -m "$msg"
then
	"new_stable.sh: Cannot create $rep_release"
	exit 1
fi
echo ""
echo "To check out this stable version use the command:"
echo "	svn_checkout.sh f2cad stable/$stable_version"
echo "To check out this release version use the command:"
echo "	svn_checkout.sh f2cad releases/$stable_version.0"
